# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from chat_server_connector.models.chat_message_attachment_read_with_metadata import ChatMessageAttachmentReadWithMetadata  # noqa: E501

class TestChatMessageAttachmentReadWithMetadata(unittest.TestCase):
    """ChatMessageAttachmentReadWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatMessageAttachmentReadWithMetadata:
        """Test ChatMessageAttachmentReadWithMetadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatMessageAttachmentReadWithMetadata`
        """
        model = ChatMessageAttachmentReadWithMetadata()  # noqa: E501
        if include_optional:
            return ChatMessageAttachmentReadWithMetadata(
                file_id = '',
                attachment_type = 'IMAGE',
                id = 56,
                file_url = '',
                full_file_name = '',
                file_size = 56,
                file_extension = '',
                mime_type = ''
            )
        else:
            return ChatMessageAttachmentReadWithMetadata(
                file_id = '',
                attachment_type = 'IMAGE',
                id = 56,
                file_url = '',
                full_file_name = '',
                file_size = 56,
                file_extension = '',
                mime_type = '',
        )
        """

    def testChatMessageAttachmentReadWithMetadata(self):
        """Test ChatMessageAttachmentReadWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
